package drawing_objects;

import entities.EntityBattleship;

import java.awt.*;

public class DrawingBattleship {
    private EntityBattleship entityBattleship;
    public EntityBattleship getEntityBattleship() {
        return entityBattleship;
    }
    private int pictureWidth;
    private int pictureHeight;
    private int startPosX;
    private int startPosY;
    private final int SHIP_WIDTH = 150;
    public int getShipWidth() {return SHIP_WIDTH;}
    private final int SHIP_HEIGHT = 50;
    public int getShipHeight() {return SHIP_HEIGHT;}
    private DrawingBlocks drawingBlocks;
    public boolean init(int speed, double weight, Color bodyColor, Color
            additionalColor, boolean turret, boolean rocketLauncher, int width, int height, int blocksNumber) {
        if (width < SHIP_WIDTH || height < SHIP_HEIGHT)
            return false;
        pictureWidth = width;
        pictureHeight = height;
        entityBattleship = new EntityBattleship();
        entityBattleship.init(speed, weight, bodyColor, additionalColor, turret, rocketLauncher);
        drawingBlocks = new DrawingBlocks();
        drawingBlocks.setNumber(blocksNumber);
        return true;
    }
    public void setPosition(int x, int y) {
        if (x < 0 || y < 0 || x + SHIP_WIDTH > pictureWidth || y + SHIP_HEIGHT > pictureHeight) {
            x = 0;
            y = 0;
        }
        startPosX = x;
        startPosY = y;
    }
    public void moveTransport(DirectionType direction) {
        if (entityBattleship == null)
            return;
        switch (direction) {
            //влево
            case LEFT -> {
                if (startPosX - entityBattleship.step.get().intValue() > 0)
                    startPosX -= entityBattleship.step.get().intValue();
            }
            //вверх
            case UP -> {
                if (startPosY - entityBattleship.step.get().intValue() > 0)
                    startPosY -= entityBattleship.step.get().intValue();
            }
            // вправо
            case RIGHT -> {
                if (startPosX + SHIP_WIDTH + entityBattleship.step.get().intValue() < pictureWidth)
                    startPosX += entityBattleship.step.get().intValue();
            }
            //вниз
            case DOWN -> {
                if (startPosY + SHIP_HEIGHT + entityBattleship.step.get().intValue() < pictureHeight)
                    startPosY += entityBattleship.step.get().intValue();
            }
        }
    }
    public void drawTransport(Graphics2D graphics2D) {
        if (entityBattleship == null)
            return;
        BasicStroke pen = new BasicStroke(2);
        graphics2D.setStroke(pen);
        Color bodyColor = entityBattleship.getBodyColor();
        Color additionalColor = entityBattleship.getAdditionalColor();
        //корпус
        int[] hullX = new int[] {startPosX + 5, startPosX + 100, startPosX + 150, startPosX + 100, startPosX + 5};
        int[] hullY = new int[] {startPosY, startPosY, startPosY + 25, startPosY + 50, startPosY + 50};
        graphics2D.setPaint(bodyColor);
        graphics2D.fillPolygon(hullX, hullY, 5);
        graphics2D.setPaint(Color.BLACK);
        graphics2D.drawPolygon(hullX, hullY, 5);
        graphics2D.fillRect(startPosX, startPosY + 6, 5, 13);
        graphics2D.fillRect(startPosX, startPosY + 31, 5, 13);
        //надстройки
        graphics2D.setPaint(Color.DARK_GRAY);
        graphics2D.fillRect(startPosX + 40, startPosY + 20, 30, 10);
        graphics2D.fillRect(startPosX + 70, startPosY + 12, 18, 26);
        graphics2D.fillOval(startPosX + 94, startPosY + 19, 12, 12);
        graphics2D.setPaint(Color.BLACK);
        graphics2D.drawRect(startPosX + 40, startPosY + 20, 30, 10);
        graphics2D.drawRect(startPosX + 70, startPosY + 12, 18, 26);
        graphics2D.drawOval(startPosX + 94, startPosY + 19, 12, 12);
        //блоки
        if (drawingBlocks != null){
            drawingBlocks.drawBlocks(graphics2D, startPosX, startPosY);
        }
        //орудийная башня
        if (entityBattleship.getTurret()) {
            int[] shieldX = new int[] {startPosX + 112, startPosX + 112, startPosX + 119, startPosX + 119, };
            int[] shieldY = new int[] {startPosY + 19, startPosY + 31, startPosY + 28, startPosY + 22};
            graphics2D.setPaint(additionalColor);
            graphics2D.fillPolygon(shieldX, shieldY, 4);
            graphics2D.fillRect(startPosX + 119, startPosY + 24, 12, 2);
            graphics2D.setPaint(Color.BLACK);
            graphics2D.drawPolygon(shieldX, shieldY, 4);
            graphics2D.drawRect(startPosX + 119, startPosY + 24, 12, 2);
        }
        //ячейки для ракет
        if (entityBattleship.getRocketLauncher()) {
            graphics2D.setPaint(additionalColor);
            graphics2D.fillRect(startPosX + 14, startPosY + 14, 10, 10);
            graphics2D.fillRect(startPosX + 26, startPosY + 14, 10, 10);
            graphics2D.fillRect(startPosX + 14, startPosY + 26, 10, 10);
            graphics2D.fillRect(startPosX + 26, startPosY + 26, 10, 10);
            graphics2D.setPaint(Color.BLACK);
            graphics2D.drawRect(startPosX + 14, startPosY + 14, 10, 10);
            graphics2D.drawRect(startPosX + 26, startPosY + 14, 10, 10);
            graphics2D.drawRect(startPosX + 14, startPosY + 26, 10, 10);
            graphics2D.drawRect(startPosX + 26, startPosY + 26, 10, 10);
        }
    }
}